/****************************************************************************************
 * Copyright (C) 2012 Lucien XU <sfietkonstantin@free.fr>                               *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 3 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

import QtQuick 1.1
import com.nokia.meego 1.0
import org.nemomobile.social 1.0

import "../UiConstants.js" as Ui
import "../pagemanagement.js" as PageManagement
import "../composite"
import "../components"

Page {
    id: container
    property alias name: cover.name
    property alias coverUrl: cover.coverUrl

    function load() {
        model.populate()
    }

    tools: ToolBarLayout {
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: window.pageStack.pop()
        }
    }

    Cover {
        id: cover
        category: qsTr("News feed")
        z: 2
    }


    SocialNetworkModel {
        id: model
        socialNetwork: facebook
        nodeIdentifier: ME.identifier
        filters: [ContentItemTypeFilter {type: Facebook.Home}]
        dataFilters: [storyDataFilter]
    }

    ModelWatcher { model: model }

    Flickable {
        id: flickable
        anchors.top: cover.bottom
        anchors.left: parent.left; anchors.right: parent.right
        anchors.bottom: parent.bottom
        contentHeight: Ui.MARGIN_DEFAULT + column.height + Ui.MARGIN_DEFAULT

        Column {
            id: column
            anchors.top: parent.top; anchors.topMargin: Ui.MARGIN_DEFAULT
            spacing: Ui.MARGIN_DEFAULT
            Repeater {
                model: model
                delegate: Item {
                    width: container.width
                    height: content.height

                    Post {
                        id: content
                        post: model.contentItem
                        userIdentifier: ME.identifier
        //                interactive: true
                    }
                }
            }
        }

        LoadingFooter {
            anchors.top: column.bottom
            width: flickable.width
            loading: model.status != SocialNetwork.Idle && model.count != 0
        }

        onAtYEndChanged: {
            if (atYEnd && model.count > 0 && model.hasNext) {
                model.loadNext()
            }
        }

    }

    Item {
        anchors.left: parent.left; anchors.right: parent.right
        anchors.top: cover.bottom
        anchors.bottom: parent.bottom

        LoadingMessage {
            loading: model.status != SocialNetwork.Idle && model.count == 0
            anchors.centerIn: parent
        }

        EmptyStateLabel {
            visible: model.status == SocialNetwork.Idle && model.count == 0
            text: qsTr("No post")
        }
    }

    ScrollDecorator { flickableItem: flickable }
}
